@@ -78,6 +78,11 @@ def ensure_config_files():
 
 def install_pkg(pkg):
     pm = meta.get("package_manager")
+    pms = meta.get("package_managers")
+    for x in pms:
+        if pm is not None:
+            break
+        pm = x
     if pm is None:
         pm = State.config.get(State.meta.get("environment")).get("default-package-manager", None)
     if pm is None:
